**To delete a deployment**

The following ``delete-deployment`` example deletes a deployment of an API. ::

    aws apigatewayv2 delete-deployment \
        --api-id a1b2c3d4 \
        --deployment-id a1b2c3

This command produces no output.

For more information, see `API deployment <https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-basic-concept.html#apigateway-definition-api-deployment>`__ in the *Amazon API Gateway Developer Guide*.
